exceptiontools.IntervalError
============================

.. inheritance-diagram:: abjad.tools.exceptiontools.IntervalError.IntervalError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.IntervalError.IntervalError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.IntervalError.IntervalError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.IntervalError.IntervalError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.IntervalError.IntervalError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.IntervalError.IntervalError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.IntervalError.IntervalError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.IntervalError.IntervalError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.IntervalError.IntervalError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.IntervalError.IntervalError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
